Photometric Pipeline
==========================================
This pipeline will take image data that have been :doc:`reduced<../reduction/reduction>` and calculate lightcurves on the stars/sources in the field.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   self
   phot_pipeline_parameters
   example_phot_param_file
   running_phot_pipeline
   box_time_series_cookbook.ipynb
   
